@@ -1,4 +1,5 @@
 from oarepo_model_builder.utils.jinja import split_package_base_name
+
 from ..builders import OutputBuilder
 from ..outputs.cfg import CFGOutput
 
@@ -11,10 +12,10 @@ class InvenioCliSetupCfgBuilder(OutputBuilder):
 
         output: CFGOutput = self.builder.get_output("cfg", "setup.cfg")
 
-        cli_function = split_package_base_name(self.settings.python.cli_function)
+        cli_function = split_package_base_name(self.current_model.cli_function)
 
         output.add_entry_point(
             "flask.commands",
-            self.settings.kebap_package,
+            self.current_model.flask_commands_setup_cfg,
             f"{'.'.join(cli_function[:-1])}:{cli_function[-1]}",
         )
