@@ -115,7 +115,7 @@ Ref.refs["type"] = DictValidator(
 
 Ref.refs["additionalProperties"] = DictValidator(primitives="type")
 
-Ref.refs["propertyNames"] = (DictValidator(primitives="pattern"),)
+Ref.refs["propertyNames"] = DictValidator(primitives="pattern")
 
 Ref.refs["properties"] = AnyKeyDictValidator(Ref("property", "type"))
 
@@ -133,4 +133,4 @@ schema_paths = DictValidator(
     primitives="$schema,$id,type",
 )
 
-model_paths = DictValidator({"model": schema_paths})
+model_paths = schema_paths
